#!/usr/bin/env python

#For remote debugging | script.py --remote-debugging-port=4900

import sys
from PyQt5.QtCore import Qt, QUrl, QTextStream, QCoreApplication
from PyQt5.QtNetwork import QNetworkRequest
from PyQt5.QtGui import QFont, QGuiApplication
from PyQt5.QtWidgets import (QAction, QApplication, QLineEdit, 
        QMainWindow, QSizePolicy, QTextEdit, qApp, QMessageBox)
from PyQt5.QtWebEngineWidgets import (QWebEnginePage, 
        QWebEngineView, QWebEngineSettings, QWebEngineProfile)
        
from PyQt5.Qt import *
import os

#Change home page here
home = 'about:blank'

#Update user agent here
a = ('Mozilla/5.0 (Windows NT 10.1; Win64; x64; rv:86.0) '  
        'Gecko/20100101 Firefox/86.0')

#Main window class
class MainWindow(QMainWindow):
    def __init__(self, url):
        super(MainWindow, self).__init__()
    #Main window size
        self.resize(1400,1000)

    #Font sizes for widgets and windows
        font = QFont()
        font.setPointSize(14)
        self.fs = (20)
        #Set default UA
        self.agent = QWebEngineProfile(self)
        self.agent.defaultProfile().setHttpUserAgent(a)

    #Default browser settings
        self.view = QWebEngineView(self)
        self.view.setUrl(url)
        self.view.settings().setAttribute(
                QWebEngineSettings.JavascriptEnabled, True)
        self.js = "True"
        self.view.settings().setAttribute(
                QWebEngineSettings.AutoLoadImages, True)
        self.im = "True"
        self.view.settings().setAttribute(
                QWebEngineSettings.PluginsEnabled, True)
        self.view.settings().globalSettings().setFontSize(
                QWebEngineSettings.MinimumFontSize, (self.fs))
        self.view.settings().setAttribute(
                QWebEngineSettings.LocalStorageEnabled, True)
        self.setWindowIcon(QIcon(os.path.join('images', 'iconpirateghost_64x64.png')))
    #Show link url's in status bar
        self.view.page().linkHovered.connect(self.link_hovered)
        self.statusBar().setFont(font)
        self.statusBar().show()
    #Connect to signals
        self.view.loadFinished.connect(self.adjustLocation)
        self.view.titleChanged.connect(self.adjustTitle)
        self.view.loadProgress.connect(self.setProgress)
        self.view.loadFinished.connect(self.finishLoading)
    #Url bar
        self.locationEdit = QLineEdit(self)
        self.locationEdit.setSizePolicy(QSizePolicy.Expanding,
                self.locationEdit.sizePolicy().verticalPolicy())
        self.locationEdit.returnPressed.connect(self.changeLocation)
        self.locationEdit.setFont(font)
    #Toolbar
        toolBar = self.addToolBar("Url bar")
        toolBar.setFont(font)
        toolBar.addAction(self.view.pageAction(QWebEnginePage.Back))
        toolBar.addAction(self.view.pageAction(QWebEnginePage.Forward))
        toolBar.addAction(self.view.pageAction(QWebEnginePage.Reload))
        toolBar.addAction(self.view.pageAction(QWebEnginePage.Stop))
        toolBar.addWidget(self.locationEdit)        
    #Menubar
        menubar = self.menuBar()
        menubar.setFont(font)
    #File menu
        fileMenu = self.menuBar().addMenu("File")
        fileMenu.setFont(font)
        viewSourceAction = QAction("Page Source", self)
        viewSourceAction.setShortcut("Ctrl+p")
        viewSourceAction.triggered.connect(self.viewSource)
        fileMenu.addAction(viewSourceAction)

        homeAction = QAction("Home page", self)
        homeAction.setShortcut("Ctrl+h")
        homeAction.triggered.connect(self.home_page)
        fileMenu.addAction(homeAction)

        setFontSizeU = QAction("Font size +", self)
        setFontSizeU.setShortcut("Ctrl++")
        setFontSizeU.triggered.connect(self.fontPlus)
        fileMenu.addAction(setFontSizeU)

        setFontSizeD = QAction("Font size -", self)
        setFontSizeD.setShortcut("Ctrl+-")
        setFontSizeD.triggered.connect(self.fontMinus)
        fileMenu.addAction(setFontSizeD)

        exitAction = QAction ('Exit', self)
        exitAction.setShortcut("Ctrl+Q")
        exitAction.triggered.connect(qApp.quit)
        fileMenu.addAction(exitAction)
        
    #Tool menu
        toolsMenu = self.menuBar().addMenu("Tools")
        toolsMenu.setFont(font)

        jScriptOffAction = QAction("Scripts off", self)
        jScriptOffAction.triggered.connect(self.jsOff)
        toolsMenu.addAction(jScriptOffAction)

        jScriptOnAction = QAction("Scripts on", self)
        jScriptOnAction.triggered.connect(self.jsOn)
        toolsMenu.addAction(jScriptOnAction)

        imOffAction = QAction("Images off", self)
        imOffAction.triggered.connect(self.imOff)
        toolsMenu.addAction(imOffAction)

        imOnAction = QAction("Images on", self)
        imOnAction.triggered.connect(self.imOn)
        toolsMenu.addAction(imOnAction)
        
    #Main browser window
        self.setCentralWidget(self.view)
        
#Functions

#Set images on-off    
    def imOff(self):
        self.view.settings().setAttribute(
                QWebEngineSettings.AutoLoadImages, False)

    def imOn(self):
        self.view.settings().setAttribute(
                QWebEngineSettings.AutoLoadImages, True)
#Set scripts on-off
    def jsOff(self):
        self.view.settings().setAttribute(
                QWebEngineSettings.JavascriptEnabled, False)

    def jsOn(self):
        self.view.settings().setAttribute(
                QWebEngineSettings.JavascriptEnabled, True)
#Change font size
    def fontPlus(self):
        self.fs = ((self.fs) + 2)
        self.view.settings().globalSettings().setFontSize(
                QWebEngineSettings.MinimumFontSize, (self.fs))
        self.setStatusTip("Font size is " + str(self.fs))
                        
    def fontMinus(self):
        self.fs = ((self.fs) - 2)
        self.view.settings().globalSettings().setFontSize(
                QWebEngineSettings.MinimumFontSize, (self.fs))
        self.setStatusTip("Font size is " + str(self.fs))
#Home page        
    def home_page(self):
        url = QUrl(home)
        self.view.load(url)
    
#View source code
    def viewSource(self):
        accessManager = self.view.page().networkAccessManager()
        request = QNetworkRequest(self.view.url())
        reply = accessManager.get(request)
        reply.finished.connect(self.showSource)

    def showSource(self):
        reply = self.sender()
        self.textEdit = QTextEdit()
        font = QFont()
        font.setPointSize(14)
        self.textEdit.setFont(font)
        self.textEdit.setAttribute(Qt.WA_DeleteOnClose)
        self.textEdit.setGeometry(25, 25, 1000, 800)
        self.textEdit.show()
        self.textEdit.setPlainText(QTextStream(reply).readAll())
        reply.deleteLater()
        #self.textEdit.resize(1000, 800)
        #self.textEdit.move(25, 25)
#Location
    def adjustLocation(self):
        self.locationEdit.setText(self.view.url().toString())

    def changeLocation(self):
        url = QUrl.fromUserInput(self.locationEdit.text())
        self.view.load(url)
        self.view.setFocus()
#Adjust title to page
    def adjustTitle(self):
        if 0 < self.progress < 100:
            self.setWindowTitle("%s (%s%%)" % (self.view.title(), self.progress))
        else:
            self.setWindowTitle(self.view.title())
#Load progress
    def setProgress(self, p):
        self.progress = p
        self.adjustTitle()

    def finishLoading(self):
        self.progress = 100
        self.adjustTitle()
#Show links mouse hover
    def link_hovered(self, link):
        self.statusBar().showMessage(link)

if __name__ == '__main__':
    app = QApplication(sys.argv)
    
#Open with argument or home
    if len(sys.argv) > 1:
        url = QUrl(sys.argv[1])
    else:
        url = QUrl(home)
#Start the loop
    browser = MainWindow(url)
    browser.show()
    sys.exit(app.exec_())