#!/usr/bin/python

from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from PyQt5.QtWebEngineWidgets import *
from PyQt5.QtPrintSupport import *

import os
import sys
import datetime
import sqlite3
import subprocess
from subprocess import Popen

from PyQt5 import QtWebEngineWidgets
from PyQt5.QtNetwork import QNetworkRequest

connection = sqlite3.connect("webBrowserDB.db")
cursor = connection.cursor()

### USER SETTINGS ###
### Instructions: you select one of the rows below and search with the editor the selected line and go to the chosen configuration ### 

### Settings Icon size Navigation Bar ###
### Settings Icon size Address Bar ###
### Settings local browser ###
### Settings Bookmarks ###
### Settings Cookies Manager ###
### Settings translate ###
### Settings Homepage ###
### Settings web search ###

### END USER SETTINGS ###

class AboutDialog(QDialog):
    def __init__(self, *args, **kwargs):
        super(AboutDialog, self).__init__(*args, **kwargs)

        QBtn = QDialogButtonBox.Ok  # No cancel
        self.buttonBox = QDialogButtonBox(QBtn)
        self.buttonBox.accepted.connect(self.accept)
        self.buttonBox.rejected.connect(self.reject)

        layout = QVBoxLayout()

        title = QLabel("Retroplanet Navigator")
        font = title.font()
        font.setPointSize(20)
        title.setFont(font)

        layout.addWidget(title)

        logo = QLabel()
        logo.setPixmap(QPixmap(os.path.join('images', 'icon-128.png')))
        layout.addWidget(logo)

        layout.addWidget(QLabel("Version 3.0"))
        layout.addWidget(QLabel("Copyright 2021 Retroplanet."))

        for i in range(0, layout.count()):
            layout.itemAt(i).setAlignment(Qt.AlignHCenter)

        layout.addWidget(self.buttonBox)

        self.setLayout(layout)

class AboutRetroplanet(QDialog):
    def __init__(self, *args, **kwargs):
        super(AboutRetroplanet, self).__init__(*args, **kwargs)

        QBtn = QDialogButtonBox.Ok  # No cancel
        self.buttonBox = QDialogButtonBox(QBtn)
        self.buttonBox.accepted.connect(self.accept)
        self.buttonBox.rejected.connect(self.reject)

        layout = QVBoxLayout()

        title = QLabel("Retroplanet")
        font = title.font()
        font.setPointSize(20)
        title.setFont(font)

        layout.addWidget(title)

        logo = QLabel()
        logo.setPixmap(QPixmap(os.path.join('images', 'retroplanet-128.png')))
        layout.addWidget(logo)

        layout.addWidget(QLabel("License MIT"))
        layout.addWidget(QLabel("Retroplanet is licensed under an MIT license."))

        for i in range(0, layout.count()):
            layout.itemAt(i).setAlignment(Qt.AlignHCenter)

        layout.addWidget(self.buttonBox)

        self.setLayout(layout)


class MainWindow(QMainWindow):
    def __init__(self, *args, **kwargs):
        super(MainWindow, self).__init__(*args, **kwargs)

        self.connection = sqlite3.connect("webBrowserDB.db")
        self.cursor = self.connection.cursor()

        # create history table
        cursor.execute("""CREATE TABLE IF NOT EXISTS "history" (
                   "id"	INTEGER,
                   "title"	TEXT,
                   "url"	TEXT,
                   "date"	TEXT,
               	PRIMARY KEY("id")
               	)""")

        self.browser = QWebEngineView()
        self.browser.setUrl(QUrl("https://start.me/start"))
        self.browser.loadFinished.connect(self.updateHistory)

        self.browser.urlChanged.connect(self.update_urlbar)
        self.browser.loadFinished.connect(self.update_title)
        self.setCentralWidget(self.browser)

    #Show link url's in status bar
        self.browser.page().linkHovered.connect(self.link_hovered)
        self.statusBar().show()

        self.browser.settings().setAttribute(
                QWebEngineSettings.JavascriptEnabled, True)
        self.js = "True"
        self.browser.settings().setAttribute(
                QWebEngineSettings.AutoLoadImages, True)
        self.im = "True"
        self.browser.settings().setAttribute(
                QWebEngineSettings.PluginsEnabled, True)

        self.status = QStatusBar()
        self.setStatusBar(self.status)

    ### Settings Icon size Navigation Bar ###
        navtb = QToolBar("Navigation")
        navtb.setIconSize(QSize(25, 25))
        self.addToolBar(navtb)

        back_btn = QAction(QIcon(os.path.join('images/themes/icons', 'back.png')), "Back", self)
        back_btn.setStatusTip("Back to previous page")
        back_btn.triggered.connect(self.browser.back)
        navtb.addAction(back_btn)

        next_btn = QAction(QIcon(os.path.join('images/themes/icons', 'forward.png')), "Forward", self)
        next_btn.setStatusTip("Forward to next page")
        next_btn.triggered.connect(self.browser.forward)
        navtb.addAction(next_btn)

        reload_btn = QAction(QIcon(os.path.join('images/themes/icons', 'refresh.png')), "Reload", self)
        reload_btn.setStatusTip("Reload page")
        reload_btn.triggered.connect(self.browser.reload)
        navtb.addAction(reload_btn)

        home_btn = QAction(QIcon(os.path.join('images/themes/icons', 'go-home.png')), "Home", self)
        home_btn.setStatusTip("Go home")
        home_btn.triggered.connect(self.navigate_home)
        navtb.addAction(home_btn)

        search_btn = QAction(QIcon(os.path.join('images/themes/icons', 'search.png')), "Web Search", self)
        search_btn.setStatusTip("Web Search")
        search_btn.triggered.connect(self.search)
        navtb.addAction(search_btn)

        bookmarks_btn = QAction(QIcon(os.path.join('images/themes/icons', 'bookmark-view.png')), "Bookmarks - HTML", self)
        bookmarks_btn.setStatusTip("Bookmarks - HTML")
        bookmarks_btn.triggered.connect(self.bookmarks)
        navtb.addAction(bookmarks_btn)

        history_btn = QAction(QIcon(os.path.join('images/themes/icons', 'history.png')), "History", self)
        history_btn.setStatusTip("History")
        history_btn.triggered.connect(self.viewhistory)
        navtb.addAction(history_btn)

        stop_btn = QAction(QIcon(os.path.join('images/themes/icons', 'stop.png')), "Stop", self)
        stop_btn.setStatusTip("Stop loading current page")
        stop_btn.triggered.connect(self.browser.stop)
        navtb.addAction(stop_btn)

    ### Settings Icon size Address Bar ###
        addressbar = QToolBar("Url Bar")
        addressbar.setIconSize(QSize(25, 25))
        self.addToolBar(Qt.TopToolBarArea, addressbar)

#Zoom -.        
        self.zoom_out = QToolButton()
        zoomouticon = QIcon()
        zoomouticon.addPixmap(QPixmap(os.path.join('images/themes/icons', 'zoom-out.png')), QIcon.Normal, QIcon.Off)
        self.zoom_out.setIcon(zoomouticon)
        self.zoom_out.setObjectName(("zoom_out"))
        self.zoom_out.setToolTip('Zoom -')
        self.zoom_out.clicked.connect(self.zoomouts)
        self.zoom_out.setFixedSize(48, 48)
        addressbar.addWidget(self.zoom_out)

#Zoom +.       
        self.zoom_in = QToolButton()
        zoominicon = QIcon()
        zoominicon.addPixmap(QPixmap(os.path.join('images/themes/icons', 'zoom-in.png')), QIcon.Normal, QIcon.Off)
        self.zoom_in.setIcon(zoominicon)
        self.zoom_in.setObjectName(("zoom_in"))
        self.zoom_in.setToolTip('Zoom +')
        self.zoom_in.clicked.connect(self.zoomins)
        self.zoom_in.setFixedSize(48, 48)
        addressbar.addWidget(self.zoom_in)

        navtb.addSeparator()

        self.httpsicon = QLabel()  # Yes, really!
        self.httpsicon.setPixmap(QPixmap(os.path.join('images', 'lock-nossl.png')))
        addressbar.addWidget(self.httpsicon)

        self.urlbar = QLineEdit()
        self.urlbar.returnPressed.connect(self.navigate_to_url)
        addressbar.addWidget(self.urlbar)

        enter_btn = QAction(QIcon(os.path.join('images/themes/icons', 'key_enter.png')), "Go", self)
        enter_btn.setStatusTip("Go")
        enter_btn.triggered.connect(self.navigate_to_url)
        addressbar.addAction(enter_btn)

        addressbar.addSeparator()

        #Download.        
        self.download = QToolButton()
        downloadicon = QIcon()
        downloadicon.addPixmap(QPixmap(os.path.join('images/themes/icons', 'document-save.png')), QIcon.Normal, QIcon.Off)
        self.download.setIcon(downloadicon)
        self.download.setObjectName(("download"))
        self.download.setToolTip('Download file from location')
        self.download.clicked.connect(self.downloads)
        self.download.setFixedSize(48, 48)
        addressbar.addWidget(self.download)        

        about_btn = QAction(QIcon(os.path.join('images', 'icon02-64.png')), "About Retroplanet Navigator", self)
        about_btn.setStatusTip("Find out more about Retroplanet Navigator")  # Hungry!
        about_btn.triggered.connect(self.about)
        addressbar.addAction(about_btn)

        # Uncomment to disable native menubar on Mac
        # self.menuBar().setNativeMenuBar(False)

        file_menu = self.menuBar().addMenu("&File")

        new_tab_action = QAction(QIcon(os.path.join('images', 'iconparrot64x64.png')), "Multi Tab Version", self)
        new_tab_action.setStatusTip("Multi tab version")
        new_tab_action.triggered.connect(lambda _: self.tabbed())
        file_menu.addAction(new_tab_action)

        new_window_action = QAction(QIcon(os.path.join('images', 'icon02-64.png')), "Open new window", self)
        new_window_action.setStatusTip("Open new window")
        new_window_action.triggered.connect(self.new_window)
        file_menu.addAction(new_window_action)

        privatenavigator_action = QAction(QIcon(os.path.join('images', 'iconpirateghost_64x64.png')), "Private Navigator", self)
        privatenavigator_action.setStatusTip("Private Navigator")
        privatenavigator_action.triggered.connect(self.privatenavigator)
        file_menu.addAction(privatenavigator_action)

        kiosk_action = QAction(QIcon(os.path.join('images', 'tucan-155252_64.png')), "Retroplanet Kiosk", self)
        kiosk_action.setStatusTip("Retroplanet Kiosk")
        kiosk_action.triggered.connect(self.kiosk)
        file_menu.addAction(kiosk_action)

        file_menu.addSeparator()

        open_file_action = QAction(QIcon(os.path.join('images/themes/icons', 'document-open.png')), "Open file...", self)
        open_file_action.setStatusTip("Open from file")
        open_file_action.triggered.connect(self.open_file)
        file_menu.addAction(open_file_action)

        save_file_action = QAction(QIcon(os.path.join('images/themes/icons', 'document-save-as.png')), "Save Page As...", self)
        save_file_action.setStatusTip("Save current page to file")
        save_file_action.triggered.connect(self.save_file)
        file_menu.addAction(save_file_action)

        print_action = QAction(QIcon(os.path.join('images/themes/icons', 'printer.png')), "Print...", self)
        print_action.setStatusTip("Print current page")
        print_action.triggered.connect(self.print_page)
        file_menu.addAction(print_action)


        quit_action = QAction(QIcon(os.path.join('images/themes/icons', 'application-exit.png')), "Quit...", self)
        quit_action.setStatusTip("Quit")
        quit_action.triggered.connect(qApp.quit)
        file_menu.addAction(quit_action)

        edit_menu = self.menuBar().addMenu("&Edit")

        jScriptOff_action = QAction("Scripts off", self)
        jScriptOff_action.triggered.connect(self.jsOff)
        edit_menu.addAction(jScriptOff_action)

        jScriptOn_action = QAction("Scripts on", self)
        jScriptOn_action.triggered.connect(self.jsOn)
        edit_menu.addAction(jScriptOn_action)

        edit_menu.addSeparator()

        imOff_action = QAction("Images off", self)
        imOff_action.triggered.connect(self.imOff)
        edit_menu.addAction(imOff_action)

        imOn_action = QAction("Images on", self)
        imOn_action.triggered.connect(self.imOn)
        edit_menu.addAction(imOn_action)

        bookmarks_menu = self.menuBar().addMenu("&Bookmarks")

        bookmarks_action = QAction(QIcon(os.path.join('images/themes/icons', 'bookmark-view.png')), "Bookmarks - HTML", self)
        bookmarks_action.setStatusTip("Bookmarks - HTML")
        bookmarks_action.triggered.connect(self.bookmarks)
        bookmarks_menu.addAction(bookmarks_action)

        viewbookmarks_action = QAction(QIcon(os.path.join('images/themes/icons', 'document-open.png')), "Open bookmarks - HTML", self)
        viewbookmarks_action.setStatusTip("Open bookmarks - HTML")
        viewbookmarks_action.triggered.connect(self.open_file)
        bookmarks_menu.addAction(viewbookmarks_action)

        startme_action = QAction(QIcon(os.path.join('images', 'startme.png')), "Start.me", self)
        startme_action.setStatusTip("Startme")
        startme_action.triggered.connect(self.startme)
        bookmarks_menu.addAction(startme_action)

        opendesktop_action = QAction(QIcon(os.path.join('images', 'opendesktop.png')), "Opendesktop", self)
        opendesktop_action.setStatusTip("Opendesktop")
        opendesktop_action.triggered.connect(self.opendesktop)
        bookmarks_menu.addAction(opendesktop_action)

        ilporto_action = QAction(QIcon(os.path.join('images', 'ilporto.jpeg')), "Il Porto", self)
        ilporto_action.setStatusTip("Il Porto")
        ilporto_action.triggered.connect(self.ilporto)
        bookmarks_menu.addAction(ilporto_action)

        emojiunicode_action = QAction(QIcon(os.path.join('images', '1f600.png')), "Emoji Unicode", self)
        emojiunicode_action.setStatusTip("Emoji Unicode")
        emojiunicode_action.triggered.connect(self.emojiunicode)
        bookmarks_menu.addAction(emojiunicode_action)

        tools_menu = self.menuBar().addMenu("&Tools")

        aboutblank_action = QAction("About blank", self)
        aboutblank_action.setStatusTip("About blank")
        aboutblank_action.triggered.connect(self.aboutblank)
        tools_menu.addAction(aboutblank_action)
        
        network_action = QAction(QIcon(os.path.join('images/themes/icons', 'network.png')), "Network", self)
        network_action.setStatusTip("Network")
        network_action.triggered.connect(self.network)
        tools_menu.addAction(network_action)
        
        cups_action = QAction(QIcon(os.path.join('images/themes/icons', 'printer.png')), "Cups", self)
        cups_action.setStatusTip("Cups")
        cups_action.triggered.connect(self.cups)
        tools_menu.addAction(cups_action)

        local_action = QAction(QIcon(os.path.join('images/themes/icons', 'computer.png')), "Local", self)
        local_action.setStatusTip("Local")
        local_action.triggered.connect(self.local)
        tools_menu.addAction(local_action)

        localbrowser_action = QAction(QIcon(os.path.join('images/themes/icons', 'user.png')), "Local Browser", self)
        localbrowser_action.setStatusTip("Local Browser")
        localbrowser_action.triggered.connect(self.localbrowser)
        tools_menu.addAction(localbrowser_action)

        tools_menu.addSeparator()

        translate_action = QAction("Page Translate", self)
        translate_action.setStatusTip("Page Translate")
        translate_action.triggered.connect(self.translate)
        tools_menu.addAction(translate_action)

        tools_menu.addSeparator()

        hideme_action = QAction("hide.me-proxy", self)
        hideme_action.setStatusTip("hide.me-proxy")
        hideme_action.triggered.connect(self.hideme)
        tools_menu.addAction(hideme_action)

        proxy4everproxy_action = QAction("4everproxy", self)
        proxy4everproxy_action.setStatusTip("4everproxy")
        proxy4everproxy_action.triggered.connect(self.proxy4everproxy)
        tools_menu.addAction(proxy4everproxy_action)

        webproxylist_action = QAction("Web Proxy List", self)
        webproxylist_action.setStatusTip("Web Proxy List")
        webproxylist_action.triggered.connect(self.webproxylist)
        tools_menu.addAction(webproxylist_action)

        tools_menu.addSeparator()

        cookies_action = QAction(QIcon(os.path.join('images/themes/icons', 'tools.png')), "Cookies Manager", self)
        cookies_action.setStatusTip("Cookies Manager")
        cookies_action.triggered.connect(self.cookies)
        tools_menu.addAction(cookies_action)

        tools_menu.addSeparator()

        find_action = QAction(QIcon(os.path.join('images/themes/icons', 'find.png')), "Find", self)
        find_action.setStatusTip("Find text")
        find_action.triggered.connect(self.findtext)
        tools_menu.addAction(find_action)

        apps_menu = self.menuBar().addMenu("&Apps")

        notepad_action = QAction(QIcon(os.path.join('images/themes/icons', 'edit.png')), "Notepad Editor", self)
        notepad_action.setStatusTip("Notepad Editor")
        notepad_action.triggered.connect(self.notepad)
        apps_menu.addAction(notepad_action)

        wordprocessor_action = QAction(QIcon(os.path.join('images/themes/icons', 'edit.png')), "Word Processor", self)
        wordprocessor_action.setStatusTip("Word Processor")
        wordprocessor_action.triggered.connect(self.wordprocessor)
        apps_menu.addAction(wordprocessor_action)

        search_menu = self.menuBar().addMenu("&Search")

        gigablast_action = QAction(QIcon(os.path.join('images/logos', 'gigablast.png')), "Gigablast", self)
        gigablast_action.setStatusTip("Gigablast")
        gigablast_action.triggered.connect(self.gigablast)
        search_menu.addAction(gigablast_action)

        mojeek_action = QAction(QIcon(os.path.join('images/logos', 'mojeek.png')), "Mojeek", self)
        mojeek_action.setStatusTip("Mojeek")
        mojeek_action.triggered.connect(self.mojeek)
        search_menu.addAction(mojeek_action)

        duckduckgo_action = QAction(QIcon(os.path.join('images/logos', 'duckduckgo.png')), "DuckDuckGo", self)
        duckduckgo_action.setStatusTip("DuckDuckGo")
        duckduckgo_action.triggered.connect(self.duckduckgo)
        search_menu.addAction(duckduckgo_action)

        google_action = QAction(QIcon(os.path.join('images/logos', 'google.png')), "Google", self)
        google_action.setStatusTip("Google")
        google_action.triggered.connect(self.google)
        search_menu.addAction(google_action)

        bing_action = QAction(QIcon(os.path.join('images/logos', 'bing.png')), "Bing", self)
        bing_action.setStatusTip("Bing")
        bing_action.triggered.connect(self.bing)
        search_menu.addAction(bing_action)

        altavista_action = QAction(QIcon(os.path.join('images/logos', 'altavista.png')), "Altavista", self)
        altavista_action.setStatusTip("Altavista")
        altavista_action.triggered.connect(self.altavista)
        search_menu.addAction(altavista_action)

        italiansearch_action = QAction(QIcon(os.path.join('images/logos', 'gigablast.png')), "Gigablast Italian Web Search", self)
        italiansearch_action.setStatusTip("Gigablast Italian Web Search")
        italiansearch_action.triggered.connect(self.italiansearch)
        search_menu.addAction(italiansearch_action)

        curlie_action = QAction(QIcon(os.path.join('images/logos', 'curlie.png')), "Curlie", self)
        curlie_action.setStatusTip("Curlie")
        curlie_action.triggered.connect(self.curlie)
        search_menu.addAction(curlie_action)

        wikipedia_action = QAction(QIcon(os.path.join('images/logos', 'wikipedia.png')), "Wikipedia", self)
        wikipedia_action.setStatusTip("Wikipedia")
        wikipedia_action.triggered.connect(self.wikipedia)
        search_menu.addAction(wikipedia_action)

        internetarchive_action = QAction(QIcon(os.path.join('images/logos', 'ia.png')), "Internet Archive", self)
        internetarchive_action.setStatusTip("Internet Archive")
        internetarchive_action.triggered.connect(self.internetarchive)
        search_menu.addAction(internetarchive_action)

        help_menu = self.menuBar().addMenu("&Help")

        about_action = QAction(QIcon(os.path.join('images/themes/icons', 'help-contents.png')), "About Retroplanet Navigator", self)
        about_action.setStatusTip("Find out more about Retroplanet Navigator")  # Hungry!
        about_action.triggered.connect(self.about)
        help_menu.addAction(about_action)

        navigate_Retroplanetnavigator_action = QAction(QIcon(os.path.join('images/themes/icons', 'help-browser.png')),
                                            "Retroplanet Navigator Homepage", self)
        navigate_Retroplanetnavigator_action.setStatusTip("Go to Retroplanet Navigator Homepage")
        navigate_Retroplanetnavigator_action.triggered.connect(self.navigate_Retroplanetnavigator)
        help_menu.addAction(navigate_Retroplanetnavigator_action)

        aboutpyqt_action = QAction(QIcon(os.path.join('images', 'pyqt.png')),
                                            "About Pyqt", self)
        aboutpyqt_action.setStatusTip("About Pyqt")
        aboutpyqt_action.triggered.connect(self.aboutpyqt)
        help_menu.addAction(aboutpyqt_action)

        aboutretroplanet_action = QAction(QIcon(os.path.join('images', 'retroplanet.png')), "About Retroplanet", self)
        aboutretroplanet_action.setStatusTip("About Retroplanet")  # Hungry!
        aboutretroplanet_action.triggered.connect(self.aboutretroplanet)
        help_menu.addAction(aboutretroplanet_action)



        self.show()

        self.setWindowIcon(QIcon(os.path.join('images', 'icon02-64.png')))

    def update_title(self):
        title = self.browser.page().title()
        self.setWindowTitle("%s - Retroplanet Navigator" % title)

    def navigate_Retroplanetnavigator(self):
        self.browser.setUrl(QUrl("http://www.lagrottadelpipistrello.altervista.org/retroplanet/index.html"))

    def about(self):
        dlg = AboutDialog()
        dlg.exec_()

    def aboutretroplanet(self):
        dlg = AboutRetroplanet()
        dlg.exec_()

    def open_file(self):
        filename, _ = QFileDialog.getOpenFileName(self, "Open file", "",
                                                  "Hypertext Markup Language (*.htm *.html);;"
                                                  "All files (*.*)")

        if filename:
            with open(filename, 'r') as f:
                html = f.read()

            self.browser.setHtml(html)
            self.urlbar.setText(filename)

    def save_file(self):
        filename, _ = QFileDialog.getSaveFileName(self, "Save Page As", "",
                                                  "Hypertext Markup Language (*.htm *html);;"
                                                  "All files (*.*)")

        if filename:
            html = self.browser.page().toHtml()
            with open(filename, 'w') as f:
                f.write(html)

    def print_page(self):
        dlg = QPrintPreviewDialog()
        dlg.paintRequested.connect(self.browser.print_)
        dlg.exec_()

    def quit():
        dlg = QApplication(sys.argv)
        dlg.sys.exit(app.exec_())
        # QApplication.quit() 

    ### Settings web search ###
    def search(self):
        self.browser.setUrl(QUrl("about:blank"))
    ### END Settings web search ###

    def gigablast(self):
        self.browser.setUrl(QUrl("https://www.gigablast.com"))

    def mojeek(self):
        self.browser.setUrl(QUrl("https://www.mojeek.com"))

    def duckduckgo(self):
        self.browser.setUrl(QUrl("https://www.duckduckgo.com"))

    def google(self):
        self.browser.setUrl(QUrl("https://www.google.com"))

    def bing(self):
        self.browser.setUrl(QUrl("https://www.bing.com"))

    def altavista(self):
        self.browser.setUrl(QUrl("http://www.lagrottadelpipistrello.altervista.org/altavista/altavista.html"))

    def italiansearch(self):
        self.browser.setUrl(QUrl("https://www.gigablast.com/?c=main&qlangcountry=it-it"))

    def curlie(self):
        self.browser.setUrl(QUrl("https://www.curlie.org"))

    def wikipedia(self):
        self.browser.setUrl(QUrl("https://www.wikipedia.org"))

    def internetarchive(self):
        self.browser.setUrl(QUrl("https://web.archive.org"))

    def startme(self):
        self.browser.setUrl(QUrl("https://start.me/start"))

    def opendesktop(self):
        self.browser.setUrl(QUrl("https://www.opendesktop.org"))

    def aboutpyqt(self):
        self.browser.setUrl(QUrl("https://pythonpyqt.com"))

    def ilporto(self):
        self.browser.setUrl(QUrl("https://www.porto.it"))

    def network(self):
        self.browser.setUrl(QUrl("http://192.168.1.1"))   

    def cups(self):
        self.browser.setUrl(QUrl("http://localhost:631"))

    def local(self):
        self.browser.setUrl(QUrl("file://"))

    def aboutblank(self):
        self.browser.setUrl(QUrl("about:blank"))

    ### Settings local browser ###
    def localbrowser(self):
        self.browser.setUrl(QUrl("file:///home/"))

    ### Settings Bookmarks ###
    def bookmarks(self):
        self.browser.setUrl(QUrl("file:///home/"))

    ### Settings translate ###
    def translate(self):
        self.browser.setUrl(QUrl("https://translate.google.com/translate?sl=auto&tl=en&u=http://"))

    def notepad(self):
        self.p = QProcess()
        self.p.start("sh", ['notepad.sh'])

    def wordprocessor(self):
        self.p = QProcess()
        self.p.start("sh", ['wordprocessor.sh'])

    ### Settings Homepage ###
    def navigate_home(self):
        self.browser.setUrl(QUrl("about:blank"))

    def navigate_to_url(self):  # Does not receive the Url
        q = QUrl(self.urlbar.text())
        if q.scheme() == "":
            q.setScheme("http")

        self.browser.setUrl(q)

    def update_urlbar(self, q):

        if q.scheme() == 'https':
            # Secure padlock icon
            self.httpsicon.setPixmap(QPixmap(os.path.join('images', 'lock-ssl.png')))

        else:
            # Insecure padlock icon
            self.httpsicon.setPixmap(QPixmap(os.path.join('images', 'lock-nossl.png')))

        self.urlbar.setText(q.toString())
        self.urlbar.setCursorPosition(0)
        self.updateHistory()

    def privatenavigator(self):
        self.p = QProcess()
        self.p.start("sh", ['start_private.sh'])

    def kiosk(self):
        self.p = QProcess()
        self.p.start("sh", ['start_kiosk.sh'])

    def updateHistory(self):
        title = self.browser.title()
        url = str(self.browser.url())
        url = url[19:len(url) - 2]
        hour = datetime.datetime.now().strftime("%X")
        day = datetime.datetime.now().strftime("%x")
        date = hour + " - " + day
        data = self.cursor.execute("SELECT * FROM history")
        siteInfoList = data.fetchall()

        for i in range(len(siteInfoList)):
            if url == siteInfoList[i][2]: #url ler eşleşirse eski urlyi sil
                self.cursor.execute("DELETE FROM history WHERE url = ?", [url])

        self.cursor.execute("INSERT INTO history (title,url,date) VALUES (?,?,?)", (title,url,date))
        self.connection.commit()

    def viewhistory(self):
        self.p = QProcess()
        self.p.start("sqlitebrowser", ['webBrowserDB.db'])

    ### Settings Cookies Manager ###
    def cookies(self):
        self.p = QProcess()
        self.p.start("sqlitebrowser", ['/home/USERNAME/.local/share/Retroplanet/Retroplanet Navigator/QtWebEngine/Default/Cookies'])

#Set images on-off    
    def imOff(self):
        self.browser.settings().setAttribute(
                QWebEngineSettings.AutoLoadImages, False)

    def imOn(self):
        self.browser.settings().setAttribute(
                QWebEngineSettings.AutoLoadImages, True)
#Set scripts on-off
    def jsOff(self):
        self.browser.settings().setAttribute(
                QWebEngineSettings.JavascriptEnabled, False)

    def jsOn(self):
        self.browser.settings().setAttribute(
                QWebEngineSettings.JavascriptEnabled, True)

    def findtext(self):
        self.p = QProcess()
        self.p.start("sh", ['finditem.sh'])

    def tabbed(self):
        self.p = QProcess()
        self.p.start("sh", ['start_parrot.sh'])

#Page Zoom functions.
   
    def zoomins(self):
        self.browser.setZoomFactor(self.browser.zoomFactor()+.2)

    def zoomouts(self):
        self.browser.setZoomFactor(self.browser.zoomFactor()-.2)

    def downloads(self):    
        options = QFileDialog.Options()
        options |= QFileDialog.DontUseNativeDialog
        fileName, _ = QFileDialog.getSaveFileName(self.browser,"Save as","","All Files (*)", options=options)
        address=self.urlbar.text()
        if fileName:
            subprocess.Popen(['wget', address, '-O', fileName])

    def new_window(self):
        self.p = QProcess()
        self.p.start("sh", ['start.sh'])

    def emojiunicode(self):
        self.p = QProcess()
        self.p.start("sh", ['emoji.sh'])

#Show links mouse hover
    def link_hovered(self, link):
        self.statusBar().showMessage(link)

    def hideme(self):
        self.browser.setUrl(QUrl("https://hide.me/en/proxy"))

    def proxy4everproxy(self):
        self.browser.setUrl(QUrl("https://www.4everproxy.com/"))

    def webproxylist(self):
        self.browser.setUrl(QUrl("https://mmoapi.com/web-proxy"))



app = QApplication(sys.argv)
app.setApplicationName("Retroplanet Navigator")
app.setOrganizationName("Retroplanet")
app.setOrganizationDomain("http://www.lagrottadelpipistrello.altervista.org/retroplanet/index.html")

window = MainWindow()

browser = MainWindow
app.exec_()
